/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.framework;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;



/**
 * Class representing raster image on which shapes are rendered.
 * 
 * @author Pavel Tisnovsky
 */
public class TestImage
{
    /**
     * Simple logger object.
     */
    private Log log = null;

    /**
     * Size of grid used to draw image background.
     */
    private static final int GRID_SIZE = 20;

    /**
     * Object representing the raster canvas.
     */
    private BufferedImage image = null;

    /**
     * Implicit constructor should be disabled for this object type.
     */
    @SuppressWarnings("unused")
    private TestImage()
    {
        // empty as expected :-)
    }

    /**
     * Initialization of TestImage object.
     * 
     * @param configuration
     *            configuration of current test suite
     * @param zoom
     *            zoom factor
     */
    public TestImage(GfxTestConfiguration configuration, int zoom)
    {
        this.log = new Log(this.getClass().getName(), false);
        this.createImage(configuration, zoom);
    }

    /**
     * Initialization of TestImage object.
     * 
     * @param width
     *            image width
     * @param height
     *            image height
     */
    public TestImage(int width, int height)
    {
        this.log = new Log(this.getClass().getName(), false);
        this.createImage(width, height);
    }

    /**
     * Initialization of TestImage object.
     * 
     * @param width
     *            image width
     * @param height
     *            image height
     */
    public TestImage(double width, double height)
    {
        this.log = new Log(this.getClass().getName(), false);
        this.createImage((int)width, (int)height);
    }

    /**
     * Create new buffered image with given width and height.
     * 
     * @param width
     *            image width
     * @param height
     *            image height
     */
    public void createImage(int width, int height)
    {
        this.image = new BufferedImage(width, height, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Create new buffered image with given width, height and image type.
     * 
     * @param configuration
     *            configuration of current test suite
     * @param zoom
     *            zoom factor
     */
    public void createImage(GfxTestConfiguration configuration, int zoom)
    {
        this.image = new BufferedImage(configuration.getImageWidth() / zoom, configuration.getImageHeight() / zoom,
                configuration.getImageType());
        this.clearImage();
        if (zoom == 1)
        {
            this.drawGrid();
        }
    }

    /**
     * Clear the background of the test image ie. fill the whole image with
     * white color.
     */
    protected void clearImage()
    {
        fillImage(Color.WHITE);
    }

    /**
     * Fill whole image using given color.
     * 
     * @param color
     *            color used to fill whole image.
     */
    public void fillImage(Color color)
    {
        Graphics2D graphics = this.image.createGraphics();
        graphics.setColor(color);
        graphics.fillRect(0, 0, this.image.getWidth(), this.image.getHeight());
        graphics.dispose();
    }

    /**
     * Read raster image from external file.
     * 
     * @param directory
     *            directory containing the image
     * @param fileName
     *            raster image file name
     * @return image read from external file
     * @throws IOException
     */
    @SuppressWarnings("nls")
    protected BufferedImage readImage(File directory, String fileName) throws IOException
    {
        this.log.log("reading image " + fileName + " from directory " + directory);
        File imageFile = new File(directory, fileName);
        return ImageIO.read(imageFile);
    }

    /**
     * Write raster image to an external file.
     * 
     * @param directory
     *            directory containing the image
     * @param fileName
     *            raster image file name
     * @throws IOException
     */
    @SuppressWarnings("nls")
    private void writeImage(File directory, String fileName) throws IOException
    {
        this.log.log("writing image " + fileName + " into directory " + directory);
        ImageIO.write(this.image, "png", new File(directory, fileName));
    }

    /**
     * Write given buffered image to PNG file.
     * 
     * @param configuration
     *            current configuration of GfxTest framework
     * @param suiteName
     *            name of test suite
     * @param testName
     *            name of test from the given test suite
     * @throws IOException
     *             can occurs during PNG file creation
     */
    @SuppressWarnings("nls")
    public void writeImage(GfxTestConfiguration configuration, String suiteName, String testName) throws IOException
    {
        this.writeImage(configuration.getOutputPath(), suiteName + "_" + testName + ".png");
    }
    
    /**
     * This method draws grid below the test (rendered) pattern.
     * 
     * @param image
     *            reference to the image created by test case
     */
    private void drawGrid()
    {
        Graphics2D graphics = this.image.createGraphics();
        graphics.setColor(new Color(0xa0, 0xa0, 0xff));
        // draw vertical lines
        for (int x = 0; x < this.image.getWidth(); x += GRID_SIZE)
        {
            graphics.drawLine(x, 0, x, this.image.getHeight() - 1);
        }
        // draw horizontal lines
        for (int y = 0; y < this.image.getHeight(); y += GRID_SIZE)
        {
            graphics.drawLine(0, y, this.image.getWidth() - 1, y);
        }
        graphics.dispose();
    }

    /**
     * Returns graphics2d object for this instance of test image.
     * 
     * @return graphics2d object for this instance of test image.
     */
    public Graphics2D getGraphics()
    {
        Graphics2D graphics2d = (Graphics2D) this.image.getGraphics();
        graphics2d.setRenderingHint(java.awt.RenderingHints.KEY_STROKE_CONTROL, java.awt.RenderingHints.VALUE_STROKE_PURE);
        return graphics2d;
    }

    /**
     * Return width of the test image.
     * 
     * @return width of the test image.
     */
    public int getWidth()
    {
        return this.image.getWidth();
    }

    /**
     * Return height of the test image.
     * 
     * @return height of the test image.
     */
    public int getHeight()
    {
        return this.image.getHeight();
    }

    /**
     * Return the value used to draw a grid on the background of the image.
     *
     * @return grid size
     */
    public int getGrid()
    {
        return GRID_SIZE;
    }

    /**
     * Return x-coordinate of the center of the test image.
     * 
     * @return x-coordinate of the center of the test image.
     */
    public int getCenterX()
    {
        return this.getWidth() >> 1;
    }

    /**
     * Return y-coordinate of the center of the test image.
     * 
     * @return y-coordinate of the center of the test image.
     */
    public int getCenterY()
    {
        return this.getHeight() >> 1;
    }

    /**
     * Return pixel color at given coordinates.
     * 
     * @param x
     *            the x coordinate of the pixel from which to get the color
     * @param y
     *            the y coordinate of the pixel from which to get the color
     * @return color in the default sRGB color space
     */
    public int getRGB(int x, int y)
    {
        return this.image.getRGB(x, y);
    }

    /**
     * Set color of pixel at given coordinates.
     * 
     * @param x
     *            the x coordinate of the pixel to set the color
     * @param y
     *            the y coordinate of the pixel to set the color
     * @param rgb
     *            color in the default sRGB color space
     */
    public void setRGB(int x, int y, int rgb)
    {
        this.image.setRGB(x, y, rgb);
    }

    /**
     * Get the raster image on which this project is based.
     * 
     * @return raster image
     */
    public BufferedImage getImage()
    {
        return this.image;
    }
}
