/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012, 2013, 2014  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.geom.Area;



import org.gfxtest.framework.CommonCAGOperations;
import org.gfxtest.framework.CommonRenderingStyles;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test checks the process of creating and rendering new geometric shapes
 * by performing boolean operations on existing ones. This process is often
 * called Constructive area geometry (CAG). Various cases are checked by this
 * test suite.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.AREA)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class CAGOperationsOnCircleAndRectangle extends GfxTest
{

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleUnionStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using Xor operator.
     * The shape is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleXorStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleUnionWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleIntersectWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleInverseSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using Xor operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleXorWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleUnionExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape
     * is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleIntersectExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape
     * is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleInverseSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using Xor operator.
     * The shape is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleXorExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleUnionColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleInverseSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleIntersectColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }


    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleXorColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleUnionRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleInverseSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleIntersectRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleXorRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleUnionHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleInverseSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleIntersectHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleXorHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleUnionVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleInverseSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleIntersectVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleXorVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleUnionDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleInverseSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleIntersectDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigCircleRectangleXorDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleUnionStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleXorStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleUnionWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleInverseSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleIntersectWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleXorWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleUnionExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleInverseSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleIntersectExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleXorExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke extra width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleUnionColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleInverseSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleIntersectColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }


    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleXorColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleUnionRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleInverseSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleIntersectRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleXorRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleUnionHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleInverseSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleIntersectHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleXorHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleUnionVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleInverseSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleIntersectVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleXorVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleUnionDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleInverseSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleIntersectDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallCircleInsideRectangleXorDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerCircleInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleUnionStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleXorStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleUnionWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleInverseSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleIntersectWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleXorWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleUnionExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleInverseSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleIntersectExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from circle and rectangle using XOR operator. The shape is
     * rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleXorExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke extra width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleUnionColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleInverseSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleIntersectColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleXorColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleUnionRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleInverseSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleIntersectRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleXorRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleUnionHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleInverseSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleIntersectHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleXorHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleUnionVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleInverseSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleIntersectVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleXorVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using union operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleUnionDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using subtract operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using inverse subtract operator.
     * The shape is rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleInverseSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using intersect operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleIntersectDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a circle inside a rectangle using XOR operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingCircleAndRectangleXorDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingCircleAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new CAGOperationsOnCircleAndRectangle().runTestSuite(args);
    }

}
