/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.geom.Path2D;

import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;



/**
 * These tests renders various shapes using Path2D class. Shapes are constructed
 * only from line segments.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.PATH)
@RenderStyle(RenderStyles.NORMAL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class PathsFromLines extends GfxTest
{

    /**
     * Width of border where lines are not drawn
     */
    private static final int BORDER_WIDTH = 30;

    /**
     * Step used for drawing sequence of horizontal and/or vertical lines
     */
    private static final int STEP = 20;

    /**
     * This method creates Path2D consisting of just one line.
     * 
     * @param x1
     *            the first point's x coordinate.
     * @param y1
     *            the first point's y coordinate.
     * @param x2
     *            the second point's x coordinate.
     * @param y2
     *            the second point's y coordinate.
     * @return created Path2D object
     */
    private static Path2D createLinePath(int x1, int y1, int x2, int y2)
    {
        Path2D path = new Path2D.Float();
        path.moveTo(x1, y1);
        path.lineTo(x2, y2);
        return path;
    }
    
    /**
     * This method creates horizontal Path2D consisting of just one line.
     * 
     * @param y
     *            both end point's y coordinate
     * @param width
     *            line width (not including borders)
     * @return created Path2D object
     */
    private static Path2D createHorizontalLinePath(int y, int width)
    {
        return createLinePath(BORDER_WIDTH, y, width - BORDER_WIDTH, y);
    }

    /**
     * This method creates vertical Path2D consisting of just one line.
     * 
     * @param x
     *            both end point's x coordinate
     * @param height
     *            line height (not including borders)
     * @return created Path2D object
     */
    private static Path2D createVerticalLinePath(int x, int height)
    {
        return createLinePath(x, BORDER_WIDTH, x, height - BORDER_WIDTH);
    }
    
    /**
     * This method creates Path2D consisting of two line segments, using right
     * angle between these segments.
     * 
     * @param width
     *            image width (not including borders)
     * @param height
     *            image height (not including borders)
     * @return created Path2D object
     */
    private static Path2D createPathContainingRightAngleLShape(int width, int height)
    {
        Path2D path = new Path2D.Float();
        path.moveTo(BORDER_WIDTH, BORDER_WIDTH);
        path.lineTo(BORDER_WIDTH, height - BORDER_WIDTH);
        path.lineTo(width - BORDER_WIDTH, height - BORDER_WIDTH);
        return path;
    }

    /**
     * This method creates Path2D consisting of two line segments, using right
     * angle between these segments.
     * 
     * @param width
     *            image width (not including borders)
     * @param height
     *            image height (not including borders)
     * @return created Path2D object
     */
    private static Path2D createPathContainingRightAngleVShape(int width, int height)
    {
        // calculate horizontal and vertical length of line segments
        int length = width > height ? height : width;
        length >>= 1;

        // calculate center point
        int xCenter = width >> 1;

        // create path2D
        Path2D path = new Path2D.Float();
        path.moveTo(xCenter - length, BORDER_WIDTH);
        path.lineTo(xCenter, BORDER_WIDTH + length);
        path.lineTo(xCenter + length, BORDER_WIDTH);
        return path;
    }

    /**
     * Computes color for line drawn by different angle
     * 
     * @param index
     *            counter
     * @return color computed for a given index
     */
    private static Color computeColorForSlopedLine(int index)
    {
        return new Color(Color.HSBtoRGB((float) index / ANGLES, 1.0f, 1.0f));
    }
    
    /**
     * This method created sloped line using Path2D class.
     * 
     * @param xc
     *            x-coordinate of center of test image
     * @param yc
     *            y-coordinate of center of test image
     * @param index
     *            counter
     * @return new sloped line represented by an instance of Path2D
     */
    private static Path2D createSlopedLine(int xc, int yc, int index)
    {
        int majorRadius = (xc > yc ? yc : xc) - 20;
        double angle = 2.0 * index / ANGLES * Math.PI;
        double cos = Math.cos(angle);
        double sin = Math.sin(angle);

        // calculate line end points
        int x1 = xc + (int) (MINOR_RADIUS * cos);
        int y1 = yc + (int) (MINOR_RADIUS * sin);
        int x2 = xc + (int) (majorRadius * cos);
        int y2 = yc + (int) (majorRadius * sin);

        // create new path
        return createLinePath(x1, y1, x2, y2);
    }

    /**
     * Draw path consisting of two line segments using right angle between two
     * segments. The final path is similar to L-shape.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    private static TestResult drawPathWithRightAngleLShape(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // create path
        Path2D path = createPathContainingRightAngleLShape(image.getWidth(), image.getHeight());

        // draw path
        graphics.draw(path);

        // return value
        return TestResult.PASSED;
    }

    /**
     * Draw path consisting of two line segments using right angle between two
     * segments. The final path is similar to V-shape.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    private static TestResult drawPathWithRightAngleVShape(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // create path
        Path2D path = createPathContainingRightAngleVShape(image.getWidth(), image.getHeight());

        // draw path
        graphics.draw(path);

        // return value
        return TestResult.PASSED;
    }

    /**
     * Draw color wheel using 'ANGLES' lines
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    private static void drawColorWheel(TestImage image, Graphics2D graphics)
    {
        // compute center of the image
        int xc = image.getCenterX();
        int yc = image.getCenterY();
        for (int i = 0; i < ANGLES; i++)
        {
            // set line color
            graphics.setColor(computeColorForSlopedLine(i));
            
            // create the shape
            Path2D path = createSlopedLine(xc, yc, i);
            
            // draw the shape
            graphics.draw(path);
        }
    }

    /**
     * Test basic behavior of drawing line using Path2D.Float()
     *
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineF1(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // create new path
        Path2D path = createLinePath(BORDER_WIDTH, BORDER_WIDTH, image.getWidth() - BORDER_WIDTH, image.getHeight() - BORDER_WIDTH);

        // draw the shape
        graphics.draw(path);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw line using various angles and various colors.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    public TestResult testDrawLineAtAngles1(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        drawColorWheel(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw line using various angles and various colors and wider stroke.
     * Line end points are set to default value.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    public TestResult testDrawLineAtAngles2(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // set stroke
        graphics.setStroke(new BasicStroke(5));
        drawColorWheel(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw line using various angles and various colors and wider stroke.
     * Line end points are set to CAP_BUTT.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    public TestResult testDrawLineAtAngles3(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // set stroke
        graphics.setStroke(new BasicStroke(5, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
        drawColorWheel(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw line using various angles and various colors and wider stroke.
     * Line end points are set to CAP_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    public TestResult testDrawLineAtAngles4(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // set stroke
        graphics.setStroke(new BasicStroke(5, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
        drawColorWheel(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw line using various angles and various colors and wider stroke.
     * Line end points are set to CAP_SQUARE.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     */
    public TestResult testDrawLineAtAngles5(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);

        // set stroke
        graphics.setStroke(new BasicStroke(5, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));
        drawColorWheel(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of drawing vertical lines using Path2D.Float(). Lines
     * are drawn using various colors.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineVert1(TestImage image, Graphics2D graphics)
    {
        int colorIndex = 0;
        for (int x = BORDER_WIDTH; x < image.getWidth() - BORDER_WIDTH; x += STEP)
        {
            // set drawing color
            graphics.setColor(ColorPalette.getColor(colorIndex++));

            // create new path
            Path2D path = createVerticalLinePath(x, image.getHeight());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }
    
    /**
     * Test basic behavior of drawing vertical lines using Path2D.Float(). Lines
     * are drawn using various stroke width. Lines end points are set to default
     * values.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineVert2(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);
        float strokeWidth = 0;
        for (int x = BORDER_WIDTH; x < image.getWidth() - BORDER_WIDTH; x += STEP)
        {
            // set stroke width
            graphics.setStroke(new BasicStroke(strokeWidth));
            // increase stroke width
            strokeWidth += 0.5;

            // create new path
            Path2D path = createVerticalLinePath(x, image.getHeight());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of drawing vertical lines using Path2D.Float(). Lines
     * are drawn using various stroke width. Lines end points are set to
     * CAP_BUTT.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineVert3(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);
        float strokeWidth = 0;
        for (int x = BORDER_WIDTH; x < image.getWidth() - BORDER_WIDTH; x += STEP)
        {
            // set stroke width and caps
            graphics.setStroke(new BasicStroke(strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));

            // increase stroke width
            strokeWidth += 0.5;

            // create new path
            Path2D path = createVerticalLinePath(x, image.getHeight());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of drawing vertical lines using Path2D.Float(). Lines
     * are drawn using various stroke width. Lines end points are set to
     * CAP_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineVert4(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);
        float strokeWidth = 0;
        for (int x = BORDER_WIDTH; x < image.getWidth() - BORDER_WIDTH; x += STEP)
        {
            // set stroke width and caps
            graphics.setStroke(new BasicStroke(strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));

            // increase stroke width
            strokeWidth += 0.5;

            // create new path
            Path2D path = createVerticalLinePath(x, image.getHeight());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of drawing vertical lines using Path2D.Float(). Lines
     * are drawn using various stroke width. Lines end points are set to
     * CAP_SQUARE.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineVert5(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);
        float strokeWidth = 0;
        for (int x = BORDER_WIDTH; x < image.getWidth() - BORDER_WIDTH; x += STEP)
        {
            // set stroke width and caps
            graphics.setStroke(new BasicStroke(strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));

            // increase stroke width
            strokeWidth += 0.5;

            // create new path
            Path2D path = createVerticalLinePath(x, image.getHeight());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of drawing horizontal lines using Path2D.Float().
     * Lines are drawn using various colors.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineHors1(TestImage image, Graphics2D graphics)
    {
        int colorIndex = 0;
        for (int y = BORDER_WIDTH; y < image.getHeight() - BORDER_WIDTH; y += STEP)
        {
            // set drawing color
            graphics.setColor(ColorPalette.getColor(colorIndex++));

            // create new path
            Path2D path = createHorizontalLinePath(y, image.getWidth());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of drawing horizontal lines using Path2D.Float(). Lines
     * are drawn using various stroke width. Lines end points are set to default
     * values.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineHors2(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);
        float strokeWidth = 0;
        for (int y = BORDER_WIDTH; y < image.getHeight() - BORDER_WIDTH; y += STEP)
        {
            // set stroke width
            graphics.setStroke(new BasicStroke(strokeWidth));

            // increase stroke width
            strokeWidth += 0.5;

            // create new path
            Path2D path = createHorizontalLinePath(y, image.getWidth());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }
    
    /**
     * Test basic behavior of drawing horizontal lines using Path2D.Float().
     * Lines are drawn using various stroke width. Lines end points are set to
     * CAP_BUTT.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineHors3(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);
        float strokeWidth = 0;
        for (int y = BORDER_WIDTH; y < image.getHeight() - BORDER_WIDTH; y += STEP)
        {
            // set stroke width
            graphics.setStroke(new BasicStroke(strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));

            // increase stroke width
            strokeWidth += 0.5;

            // create new path
            Path2D path = createHorizontalLinePath(y, image.getWidth());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of drawing horizontal lines using Path2D.Float().
     * Lines are drawn using various stroke width. Lines end points are set to
     * CAP_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineHors4(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);
        float strokeWidth = 0;
        for (int y = BORDER_WIDTH; y < image.getHeight() - BORDER_WIDTH; y += STEP)
        {
            // set stroke width
            graphics.setStroke(new BasicStroke(strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));

            // increase stroke width
            strokeWidth += 0.5;

            // create new path
            Path2D path = createHorizontalLinePath(y, image.getWidth());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of drawing horizontal lines using Path2D.Float().
     * Lines are drawn using various stroke width. Lines end points are set to
     * CAP_SQUARE.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawLineHors5(TestImage image, Graphics2D graphics)
    {
        // set drawing color
        graphics.setColor(Color.BLACK);
        float strokeWidth = 0;
        for (int y = BORDER_WIDTH; y < image.getHeight() - BORDER_WIDTH; y += STEP)
        {
            // set stroke width
            graphics.setStroke(new BasicStroke(strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));

            // increase stroke width
            strokeWidth += 0.5;

            // create new path
            Path2D path = createHorizontalLinePath(y, image.getWidth());

            // draw the shape
            graphics.draw(path);
        }

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw L-shaped shape consisting of two line segments.
     *
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShape(TestImage image, Graphics2D graphics)
    {
        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and default caps & join.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapDefJoinDef(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10));

        // draw the path
        drawPathWithRightAngleLShape(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_BUTT, JOIN_BEVEL.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapButtJoinBevel(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_SQUARE, JOIN_BEVEL.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapSquareJoinBevel(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_ROUND, JOIN_BEVEL.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapRoundJoinBevel(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_BUTT, JOIN_MITER.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapButtJoinMiter(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_SQUARE, JOIN_MITER.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapSquareJoinMiter(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_ROUND, JOIN_MITER.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapRoundJoinMiter(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_BUTT, JOIN_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapButtJoinRound(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_SQUARE, JOIN_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapSquareJoinRound(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw L-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_ROUND, JOIN_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleLShapeCapRoundJoinRound(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));

        // draw the path and return test result
        return drawPathWithRightAngleLShape(image, graphics);
    }

    /**
     * Draw V-shaped shape consisting of two line segments.
     *
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShape(TestImage image, Graphics2D graphics)
    {
        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }

    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and default caps & join.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapDefJoinDef(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10));

        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }

    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_BUTT, JOIN_BEVEL.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapButtJoinBevel(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));

        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }

    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_BUTT, JOIN_MITER.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapButtJoinMiter(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));
        
        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }
    
    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_BUTT, JOIN_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapButtJoinRound(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));
        
        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }
    
    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_ROUND, JOIN_BEVEL.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapRoundJoinBevel(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
        
        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }
    
    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_ROUND, JOIN_MITER .
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapRoundJoinMiter(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));
        
        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }
    
    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_ROUND, JOIN_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapRoundJoinRound(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));
        
        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }
    
    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_SQUARE, JOIN_BEVEL.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapSquareJoinBevel(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));

        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }
    
    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_SQUARE, JOIN_MITER.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapSquareJoinMiter(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));
        
        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }
    
    /**
     * Draw V-shaped shape consisting of two line segments using 10 pixels wide
     * stroke and CAP_SQUARE, JOIN_ROUND.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRightAngleVShapeCapSquareJoinRound(TestImage image, Graphics2D graphics)
    {
        // set stroke to 10 pixel width
        graphics.setStroke(new BasicStroke(10, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));
        
        // draw the path and return test result
        return drawPathWithRightAngleVShape(image, graphics);
    }
    
    /**
     * Entry point to the test suite.
     * 
     * @param args
     *            not used in this case
     */
    public static void main(String[] args)
    {
        new PathsFromLines().runTestSuite(args);
    }
}
