/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.BasicStroke;
import java.awt.Graphics2D;



import org.gfxtest.callbacks.DiagonalLineDrawCallbacks;
import org.gfxtest.callbacks.HorizontalLineDrawCallbacks;
import org.gfxtest.callbacks.VerticalLineDrawCallbacks;
import org.gfxtest.framework.ColorPalette;
import org.gfxtest.framework.GrayscalePalette;
import org.gfxtest.framework.HSBPalette;
import org.gfxtest.framework.PrintTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test suite checks rendering of various lines.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.PRINT_TEST)
@GraphicsPrimitive(GraphicsPrimitives.LINE)
@RenderStyle(RenderStyles.NORMAL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class PrintTestLines extends PrintTest
{

    /**
     * Method which renders set of horizontal lines using various colors and
     * stroke styles. For each line, the callback function/method is called to
     * perform all required setup.
     * 
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param verticalStep
     *            between two near lines
     * @param horizontalLineDrawCallbacks
     *            class containing set of callback methods
     */
    private static void drawHorizontalLines(TestImage image, Graphics2D graphics, int verticalStep, HorizontalLineDrawCallbacks horizontalLineDrawCallbacks)
    {
        // setup rendering
        horizontalLineDrawCallbacks.setup(image, graphics);

        // image width and height
        final int width = image.getWidth();
        final int height = image.getHeight();

        // horizontal coordinates of line endpoints
        final int x1 = BORDER;
        final int x2 = width - BORDER;

        // index to color palette
        int colorIndex = 0;

        // draw all lines onto a paper
        for (int y = 0; y < height; y += verticalStep)
        {
            // setup can be made for each line
            horizontalLineDrawCallbacks.iterationCallBack(y, colorIndex++);
            // render the line
            graphics.drawLine(x1, y, x2, y);
        }

        // cleanup rendering
        horizontalLineDrawCallbacks.cleanup();
    }

    /**
     * Method which renders set of vertical lines using various colors and
     * stroke styles. For each line, the callback function/method is called to
     * perform all required setup.
     * 
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param horizontalStep
     *            between two near lines
     * @param verticalLineDrawCallbacks
     *            class containing set of callback methods
     */
    private static void drawVerticalLines(TestImage image, Graphics2D graphics, int horizontalStep, VerticalLineDrawCallbacks verticalLineDrawCallbacks)
    {
        // setup rendering
        verticalLineDrawCallbacks.setup(image, graphics);

        // image width and height
        final int width = image.getWidth();
        final int height = image.getHeight();

        // horizontal coordinates of line endpoints
        final int y1 = BORDER;
        final int y2 = height - BORDER;

        // index to color palette
        int colorIndex = 0;

        // draw all lines onto a paper
        for (int x = 0; x < width; x += horizontalStep)
        {
            // setup can be made for each line
            verticalLineDrawCallbacks.iterationCallBack(x, colorIndex++);
            // render the line
            graphics.drawLine(x, y1, x, y2);
        }

        // cleanup rendering
        verticalLineDrawCallbacks.cleanup();
    }

    /**
     * Method which renders set of diagonal lines using various colors and
     * stroke styles. For each line, the callback function/method is called to
     * perform all required setup.
     * 
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param diagonalStep
     *            between two near lines
     * @param diagonalLineDrawCallbacks
     *            class containing set of callback methods
     */
    private static void drawDiagonalLines(TestImage image, Graphics2D graphics, int diagonalStep, DiagonalLineDrawCallbacks diagonalLineDrawCallbacks)
    {
        // setup rendering
        diagonalLineDrawCallbacks.setup(image, graphics);

        // image width and height
        final int width = image.getWidth();
        final int height = image.getHeight();

        // length of the "path"
        final int length = width + height - BORDER * 8;

        // coordinates of the first line
        int x1 = BORDER;
        int y1 = BORDER;
        int x2 = BORDER;
        int y2 = BORDER;

        // index to color palette
        int colorIndex = 0;

        // draw all lines onto a paper
        for (int d = 0; d < length; d += DIAGONAL_STEP)
        {
            // first endpoint
            if (x1 < width - BORDER * 2)
            {
                x1 += DIAGONAL_STEP;
            }
            else
            {
                y1 += DIAGONAL_STEP;
            }
            // second endpoint
            if (y2 < height - BORDER * 2)
            {
                y2 += DIAGONAL_STEP;
            }
            else
            {
                x2 += DIAGONAL_STEP;
            }
            // setup can be made for each line
            diagonalLineDrawCallbacks.iterationCallBack(d, colorIndex++);
            // render the line
            graphics.drawLine(x1, y1, x2, y2);
        }

        // cleanup rendering
        diagonalLineDrawCallbacks.cleanup();
    }

    /**
     * Test basic behavior of method Graphics.drawLine(). Horizontal lines are
     * rendered with default width and default end caps. Color of all rendered
     * lines are set to black.
     * 
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesBasicStyle(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP, new HorizontalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with default width and default end caps.
     * Lines color are selected from a palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesColorPalette(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP, new HorizontalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set line color
                this.graphics.setColor(ColorPalette.getColor(index));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with default width and default end caps.
     * Lines color are selected from a color palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesColorScale(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP, new HorizontalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // compute hue value
                float hue = y * 1.0f / this.image.getHeight();
                // set line color
                this.graphics.setColor(HSBPalette.createHsbColor(hue));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with default width and default end caps.
     * Lines color are selected from a grayscale palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesGrayScale(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP, new HorizontalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // compute grayscale value
                float gray = y * 1.0f / this.image.getHeight();
                // set line color
                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and default end caps.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidth(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapButtJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapRoundJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapSquareJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapButtJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapRoundJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapSquareJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapButtJoinRound(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapRoundJoinRound(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Horizontal lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawHorizontalLinesChangeWidthCapSquareJoinRound(TestImage image, Graphics2D graphics)
    {
        drawHorizontalLines(image, graphics, VERTICAL_STEP << 1, new HorizontalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int y, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with default width and default end caps.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesBasicStyle(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP, new VerticalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with default width and default end caps.
     * Lines color are selected from a palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesColorPalette(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP, new VerticalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set line color
                this.graphics.setColor(ColorPalette.getColor(index));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with default width and default end caps.
     * Lines color are selected from a color palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesColorScale(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP, new VerticalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // compute hue value
                float hue = x * 1.0f / this.image.getWidth();
                // set line color
                this.graphics.setColor(HSBPalette.createHsbColor(hue));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with default width and default end caps.
     * Lines color are selected from a grayscale palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesGrayScale(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP, new VerticalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // compute grayscale value
                float gray = x * 1.0f / this.image.getWidth();
                // set line color
                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and default end caps.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidth(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapButtJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapRoundJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapSquareJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapButtJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapRoundJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapSquareJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapButtJoinRound(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapRoundJoinRound(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Vertical lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawVerticalLinesChangeWidthCapSquareJoinRound(TestImage image, Graphics2D graphics)
    {
        drawVerticalLines(image, graphics, HORIZONTAL_STEP << 1, new VerticalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with default width and default end caps.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesBasicStyle(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP, new DiagonalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with default width and default end caps.
     * Lines color are selected from a palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesColorPalette(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP, new DiagonalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int x, int index)
            {
                // set line color
                this.graphics.setColor(ColorPalette.getColor(index));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with default width and default end caps.
     * Lines color are selected from a color palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesColorScale(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP, new DiagonalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // compute hue value
                float hue = length * 1.0f / (this.image.getWidth() + this.image.getHeight());
                // make sure that the hue value is in range 0.0f .. 1.0f
                if (hue < 0.0f)
                {
                    hue = 0.0f;
                }
                if (hue > 1.0f)
                {
                    hue = 1.0f;
                }
                // set line color
                this.graphics.setColor(HSBPalette.createHsbColor(hue));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with default width and default end caps.
     * Lines color are selected from a grayscale palette.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesGrayScale(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP, new DiagonalLineDrawCallbacks()
        {
            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // compute grayscale value
                float gray = length * 1.0f / (this.image.getWidth() + this.image.getHeight());
                // make sure that the grayscale value is in range 0.0f .. 1.0f
                if (gray < 0.0f)
                {
                    gray = 0.0f;
                }
                if (gray > 1.0f)
                {
                    gray = 1.0f;
                }
                // set line color
                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and default end caps.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidth(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapButtJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapRoundJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapSquareJoinBevel(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapButtJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapRoundJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapSquareJoinMiter(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapButtJoinRound(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapRoundJoinRound(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawLine().
     * Diagonal lines are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which lines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawDiagonalLinesChangeWidthCapSquareJoinRound(TestImage image, Graphics2D graphics)
    {
        drawDiagonalLines(image, graphics, DIAGONAL_STEP << 1, new DiagonalLineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each line is rendered.
             */
            @Override
            public void iterationCallBack(int length, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DIAGONAL_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new PrintTestLines().runTestSuite(args);
    }
}
